@@ -12,6 +12,9 @@ e.g., aditya4_internal_uEMA_****-**-**.csv in .../aditya4_internal@timestudy_com
 """
 import os
 import sys
+
+import pandas.errors
+
 from microt_compliance_matrix.utils.convert_timestamp import *
 from glob import glob
 
@@ -133,13 +136,18 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
     csv_path = list(glob(os.path.join(date_folder_path, 'phone_promptresponse_clean*.csv')))
     if len(csv_path) == 0:
         print(date_folder_path)
-        sys.exit("No intermediate promptresponse csv file on {}".format(date_in_study))
+        print("No intermediate promptresponse csv file on {}".format(date_in_study))
+        quit()
 
     # read and filter prompt type
-    df_raw = pd.read_csv(csv_path[0])
+    try:
+        df_raw = pd.read_csv(csv_path[0])
+    except pandas.errors.EmptyDataError:
+        print("pandas.errors.EmptyDataError  : " + csv_path[0])
+
     if df_raw.shape[0] == 0:
         print("Empty prompt response file : " + csv_path[0])
-        sys.exit()
+        quit()
     df_raw = df_raw[columns_list]
 
     if "Reprompt2_Prompt_UnixTime " in df_raw.columns:
